# eric7.Tasks.TaskPropertiesDialog

Module implementing the task properties dialog.

### Global Attributes

None

### Classes

TaskPropertiesDialog | Class implementing the task properties dialog.

### Functions

None

## TaskPropertiesDialog

Class implementing the task properties dialog.

### Derived from

QDialog, Ui_TaskPropertiesDialog

### Class Attributes

None

### Class Methods

None

### Methods

TaskPropertiesDialog | Constructor
__setMode | Private method to show or hide dialog elements depending on the task kind.
getData | Public method to retrieve the dialogs data.
isManualTaskMode | Public method to check, if the dialog is in manual task mode.
setSubTaskMode | Public slot to set the sub-task mode.

### Static Methods

None

#### TaskPropertiesDialog (Constructor)

TaskPropertiesDialog(task=None, parent=None, projectOpen=False)

Constructor

task (Task)
  the task object to be shown
parent (QWidget)
  the parent widget
projectOpen (bool)
  flag indicating status of the project

#### TaskPropertiesDialog.__setMode

__setMode(isFileTask, projectOpen)

Private method to show or hide dialog elements depending on the task kind.

isFileTask (bool)
  flag indicating a file task (i.e. extracted task)
projectOpen (bool)
  flag indicating status of the project

#### TaskPropertiesDialog.getData

getData()

Public method to retrieve the dialogs data.

Return:
  tuple of description, priority, type, completion flag, project flag and long text

Return Type:
  tuple of (str, TaskPriority, TaskType, bool, bool, str)

#### TaskPropertiesDialog.isManualTaskMode

isManualTaskMode()

Public method to check, if the dialog is in manual task mode.

Return:
  flag indicating manual task mode

Return Type:
  bool

#### TaskPropertiesDialog.setSubTaskMode

setSubTaskMode(projectTask)

Public slot to set the sub-task mode.

projectTask (bool)
  flag indicating a project related task

Up